unit Animation;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ExtCtrls;

type
  TAnimation = class(TCustomControl)
  private
    FFrames      : TImageList;
    FEnabled     : Boolean;
    AnimTimer    : TTimer;
    FrameNr      : Integer;
    procedure SetFrames(Value : TImageList);
    procedure SetEnabled(Value : Boolean);
    procedure SetInterval(Value : Integer);
    function GetInterval : Integer;
  protected
    procedure Paint; override;
    procedure TimerTick(Sender : TObject);
  public
    constructor Create(AOwner : TComponent); override;
    destructor Destroy; override;
  published
    property Frames : TImageList read FFrames write SetFrames;
    property Enabled : Boolean read FEnabled write SetEnabled;
    property Interval : Integer read GetInterval write SetInterval;
  end;

procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('Gadgets', [TAnimation]);
end;

constructor TAnimation.Create(AOwner : TComponent);
begin
  inherited;
  Width:=32;
  Height:=32;
  Parent:=(AOwner as TWinControl);
  FrameNr:=0;
  FFrames:=nil;
  AnimTimer:=TTimer.Create(Self);
  AnimTimer.Interval:=100;
  AnimTimer.OnTimer:=TimerTick;
  AnimTimer.Enabled:=False;
  Enabled:=False;
end;

destructor TAnimation.Destroy;
begin
  FFrames:=nil;
  inherited;
end;

procedure TAnimation.SetFrames(Value : TImageList);
begin
  FFrames:=Value;
  Width:=FFrames.Width;
  Height:=FFrames.Height;
  Invalidate;
end;

procedure TAnimation.SetEnabled(Value : Boolean);
begin
  FEnabled:=Value;
  AnimTimer.Enabled:=Value;
  Invalidate;
end;

procedure TAnimation.SetInterval(Value : Integer);
begin
  AnimTimer.Interval:=Value;
  Invalidate;
end;

function TAnimation.GetInterval : Integer;
begin
  Result:=AnimTimer.Interval;
end;

procedure TAnimation.TimerTick(Sender : TObject);
begin
  if Assigned(FFrames) then begin
    Inc(FrameNr);
    if FrameNr = FFrames.Count then FrameNr:=0;
    Invalidate;
  end;
end;

procedure TAnimation.Paint;
begin
  inherited;
  if Assigned(FFrames) then begin
    Canvas.FillRect(Canvas.ClipRect);
    FFrames.Draw(Self.Canvas,0,0,FrameNr);
  end;
end;

end.
